netapp_ontap.models.fc_port_speed API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fc_port_speed`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FcPortSpeedSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FcPortSpeed object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `configured: str GET`

    The configured speed of the FC port in gigabits per second.

    Valid choices:

    - 1
    - 2
    - 4
    - 8
    - 10
    - 16
    - 32
    - 64
    - auto
  `maximum: str GET`

    The maximum speed supported by the FC port in gigabits per second.

    Valid choices:

    - 1
    - 2
    - 4
    - 8
    - 10
    - 16
    - 32
    - 64
    - auto